(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     93952,       1742]
NotebookOptionsPosition[     94123,       1728]
NotebookOutlinePosition[     94845,       1753]
CellTagsIndexPosition[     94802,       1750]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Determinacy of Beams\n",
 StyleBox["Qingchang Liu, Baoxing Xu \nUniversity of Virginia, 2017-10-09",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center,
 ExpressionUUID -> "1f0b3856-036c-4559-ac86-a359a58bd3e2"],

Cell[TextData[{
 "To ensure the equilibrium of a rigid body, it is not only necessary to \
satisfy the equations of equilibrium, but the body must also be properly held \
or constrained by its supports. Some bodies may have more supports than are \
necessary for equilibrium, whereas others may not have enough or the supports \
may be arranged in a particular manner that could cause the body to move.     \
                                                                              \
                                                                              \
                                   \n\[FilledCircle] If a body is supported \
by constraints that yield more unknown reactive forces than available \
equations of equilibrium, then it is ",
 StyleBox["statically indeterminate",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ".\n\[FilledCircle] If a body is supported by constraints that yield a \
minimum number of reactive forces to ensure equilibrium, then it is ",
 StyleBox["statically determinate",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ".                                                                           \
      \n\[FilledCircle] If a body is supported by constraints that yield \
fewer reactive forces than equations of equilibrium that must be satisfied, \
then it is partially constrained and ",
 StyleBox["statically unstable",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 "."
}], "Text",
 ExpressionUUID -> "50edfe98-c88f-49cd-b9d2-e658b33bf322"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`mf$$ = 1, $CellContext`mm$$ = 
    1, $CellContext`opa1$$ = 0, $CellContext`opa2$$ = 
    1, $CellContext`opa3$$ = -1, $CellContext`opa4$$ = 
    1, $CellContext`opa5$$ = 0, $CellContext`pf$$ = 0.3, $CellContext`pm$$ = 
    0.6, $CellContext`sita$$ = 90, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opa1$$], 0, 
       Row[{"Coordinates visibility", 
         Spacer[20]}]}, {1 -> "On", 0 -> "off"}}, {{
       Hold[$CellContext`opa2$$], 1, 
       Row[{"Constraints at the left end of beam", 
         Spacer[20]}]}, {1 -> "Fixed", 0 -> "Smooth pin", -1 -> "Roller"}}, {{
       Hold[$CellContext`opa3$$], -1, 
       Row[{"Constraints at the right end of beam", 
         Spacer[12]}]}, {
      1 -> "Fixed", 0 -> "Smooth pin", -1 -> "Roller", -2 -> "None"}}, {{
       Hold[$CellContext`opa3$$], -1, 
       Row[{"Constraints at the right end of beam", 
         Spacer[12]}]}, {0 -> "Smooth pin", -1 -> "Roller"}}, {{
       Hold[$CellContext`opa3$$], -1, 
       Row[{"Constraints at the right end of beam", 
         Spacer[15]}]}, {-1 -> "Roller"}}, {{
       Hold[$CellContext`pf$$], 0.3, 
       Row[{"Position of force [m]", 
         Spacer[70]}]}, 0, 1}, {{
       Hold[$CellContext`mf$$], 1, 
       Row[{"Magnitude of force [kN]", 
         Spacer[48]}]}, 0, 2}, {{
       Hold[$CellContext`sita$$], 90, 
       Row[{"Direction of Force [\[Degree]]", 
         Spacer[68]}]}, 0, 360}, {{
       Hold[$CellContext`pm$$], 0.6, 
       Row[{"Position of moment [m]", 
         Spacer[52]}]}, 0, 1}, {{
       Hold[$CellContext`mm$$], 1, 
       Row[{"Magnitude of moment [kN\[CenterDot]m]", 
         Spacer[18]}]}, 0, 2}, {{
       Hold[$CellContext`opa4$$], 1, 
       Row[{"Direction of Moment", 
         Spacer[60]}]}, {1 -> "CCW", 0 -> "CW"}}, {{
       Hold[$CellContext`opa5$$], 0, 
       Row[{"Reactive Force & Moment", 
         Spacer[32]}]}, {1 -> "On", 0 -> "Off"}}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          Manipulate`Place[2]}, {
          PaneSelector[{1 -> Column[{
               Manipulate`Place[3]}], 0 -> Column[{
               Manipulate`Place[4]}], -1 -> Column[{
               Manipulate`Place[5]}]}, 
           Dynamic[$CellContext`opa2$$]]}, {
          Manipulate`Place[6]}, {
          Manipulate`Place[7]}, {
          Manipulate`Place[8]}, {
          Manipulate`Place[9]}, {
          Manipulate`Place[10]}, {
          Manipulate`Place[11]}, {
          Manipulate`Place[12]}, {
          Row[{
            Dynamic[
             If[$CellContext`opa5$$ == 1, $CellContext`temp1, 
              Invisible[$CellContext`temp]]]}]}, {
          Row[{
            Dynamic[
             If[$CellContext`opa5$$ == 1, $CellContext`temp2, 
              Invisible[$CellContext`temp]]]}]}, {
          Row[{
            Dynamic[
             If[$CellContext`opa5$$ == 1, $CellContext`temp3, 
              Invisible[$CellContext`temp]]]}]}, {
          Row[{
            Dynamic[
             If[$CellContext`opa5$$ == 1, $CellContext`temp4, 
              Invisible[$CellContext`temp]]]}]}, {
          Row[{
            Dynamic[
             If[$CellContext`opa5$$ == 1, $CellContext`temp5, 
              Invisible[$CellContext`temp]]]}]}, {
          Row[{
            Dynamic[
             If[$CellContext`opa5$$ == 1, $CellContext`temp6, 
              Invisible[$CellContext`temp]]]}]}, {
          Row[{
            Dynamic[
             If[
              And[$CellContext`opa5$$ == 1, 
               Or[$CellContext`fnbeam == 1, $CellContext`prbeam == 
                1]], $CellContext`temp7, 
              Invisible[$CellContext`temp]]]}]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.5}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {378., {159., 167.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`opa1$765558$$ = False, $CellContext`opa2$765559$$ = 
    False, $CellContext`opa3$765560$$ = False, $CellContext`pf$765561$$ = 
    0, $CellContext`mf$765562$$ = 0, $CellContext`sita$765563$$ = 
    0, $CellContext`pm$765564$$ = 0, $CellContext`mm$765565$$ = 
    0, $CellContext`opa4$765566$$ = False, $CellContext`opa5$765567$$ = 
    False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`mf$$ = 1, $CellContext`mm$$ = 
        1, $CellContext`opa1$$ = 0, $CellContext`opa2$$ = 
        1, $CellContext`opa3$$ = -1, $CellContext`opa4$$ = 
        1, $CellContext`opa5$$ = 0, $CellContext`pf$$ = 
        0.3, $CellContext`pm$$ = 0.6, $CellContext`sita$$ = 90}, 
      "ControllerVariables" :> {
        Hold[$CellContext`opa1$$, $CellContext`opa1$765558$$, False], 
        Hold[$CellContext`opa2$$, $CellContext`opa2$765559$$, False], 
        Hold[$CellContext`opa3$$, $CellContext`opa3$765560$$, False], 
        Hold[$CellContext`pf$$, $CellContext`pf$765561$$, 0], 
        Hold[$CellContext`mf$$, $CellContext`mf$765562$$, 0], 
        Hold[$CellContext`sita$$, $CellContext`sita$765563$$, 0], 
        Hold[$CellContext`pm$$, $CellContext`pm$765564$$, 0], 
        Hold[$CellContext`mm$$, $CellContext`mm$765565$$, 0], 
        Hold[$CellContext`opa4$$, $CellContext`opa4$765566$$, False], 
        Hold[$CellContext`opa5$$, $CellContext`opa5$765567$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`size$, $CellContext`alfa$, $CellContext`L$, \
$CellContext`W$, 
         Null$, $CellContext`pa$, $CellContext`pb$, $CellContext`pe$, \
$CellContext`fixlpau$, $CellContext`fixlpad$, $CellContext`fixldx$, \
$CellContext`fixldy$, $CellContext`fixlp1$, $CellContext`fixlp2$, \
$CellContext`fixlp3$, $CellContext`fixlp4$, $CellContext`fixlp5$, \
$CellContext`fixlp6$, $CellContext`fixlp7$, $CellContext`fixlp8$, \
$CellContext`fixlp9$, $CellContext`fixlp10$, $CellContext`fixlp11$, \
$CellContext`fixlp12$, $CellContext`fixlp13$, $CellContext`fixlp14$, \
$CellContext`fixlp15$, $CellContext`fixlp16$, $CellContext`pinlta$, \
$CellContext`pinlr$, $CellContext`pinldx$, $CellContext`pinldy$, \
$CellContext`pinltb$, $CellContext`pinltc$, $CellContext`pinlal$, \
$CellContext`pinlar$, $CellContext`pinlp1$, $CellContext`pinlp2$, \
$CellContext`pinlp3$, $CellContext`pinlp4$, $CellContext`pinlp5$, \
$CellContext`pinlp6$, $CellContext`pinlp7$, $CellContext`pinlp8$, \
$CellContext`pinlp9$, $CellContext`pinlp10$, $CellContext`pinlp11$, \
$CellContext`pinlp12$, $CellContext`rolr$, $CellContext`rolc$, \
$CellContext`roldx$, $CellContext`roldy$, $CellContext`rolll$, \
$CellContext`rollr$, $CellContext`rolp1$, $CellContext`rolp2$, \
$CellContext`rolp3$, $CellContext`rolp4$, $CellContext`rolp5$, \
$CellContext`rolp6$, $CellContext`rolp7$, $CellContext`rolp8$, \
$CellContext`rolp9$, $CellContext`rolp10$, $CellContext`rolp11$, \
$CellContext`rolp12$, $CellContext`rolp13$, $CellContext`rolp14$, \
$CellContext`rolp15$, $CellContext`rolp16$, $CellContext`opaf2$, \
$CellContext`opap2$, $CellContext`opar2$, $CellContext`dwf0$, \
$CellContext`dwf1$, $CellContext`dwf2$, $CellContext`dwf3$, \
$CellContext`dwf4$, $CellContext`dwf5$, $CellContext`dwf6$, \
$CellContext`dwf7$, $CellContext`dwf8$, $CellContext`dwf9$, \
$CellContext`dwf10$, $CellContext`dwf11$, $CellContext`dwf12$, \
$CellContext`dwf13$, $CellContext`dwf14$, $CellContext`dwf15$, \
$CellContext`dwf16$, $CellContext`dwf17$, $CellContext`dw1$, \
$CellContext`dw2$, $CellContext`an$, $CellContext`m$, $CellContext`ma$, \
$CellContext`ma2$, $CellContext`label$}, $CellContext`size$ = 
         5; $CellContext`alfa$ = ($CellContext`sita$$/180) 
          Pi; $CellContext`L$ = $CellContext`size$; $CellContext`W$ = 
         0.1 $CellContext`L$; $CellContext`pa$ = {0, 0}; $CellContext`pb$ = {
          0, $CellContext`W$}; $CellContext`pe$ = {$CellContext`L$, 
           0}; $CellContext`fixlpau$ = {
          0, $CellContext`W$}; $CellContext`fixlpad$ = {
          0, -$CellContext`W$}; $CellContext`fixldx$ = {$CellContext`W$/4, 
           0}; $CellContext`fixldy$ = {
          0, $CellContext`W$/
           4}; $CellContext`fixlp1$ = $CellContext`fixlpau$; \
$CellContext`fixlp2$ = $CellContext`fixlp1$ - $CellContext`fixldx$ - \
$CellContext`fixldy$; $CellContext`fixlp3$ = $CellContext`fixlp2$ + \
$CellContext`fixldx$; $CellContext`fixlp4$ = $CellContext`fixlp3$ - \
$CellContext`fixldx$ - $CellContext`fixldy$; $CellContext`fixlp5$ = \
$CellContext`fixlp4$ + $CellContext`fixldx$; $CellContext`fixlp6$ = \
$CellContext`fixlp5$ - $CellContext`fixldx$ - $CellContext`fixldy$; \
$CellContext`fixlp7$ = $CellContext`fixlp6$ + $CellContext`fixldx$; \
$CellContext`fixlp8$ = $CellContext`fixlp7$ - $CellContext`fixldx$ - \
$CellContext`fixldy$; $CellContext`fixlp9$ = $CellContext`fixlp8$ + \
$CellContext`fixldx$; $CellContext`fixlp10$ = $CellContext`fixlp9$ - \
$CellContext`fixldx$ - $CellContext`fixldy$; $CellContext`fixlp11$ = \
$CellContext`fixlp10$ + $CellContext`fixldx$; $CellContext`fixlp12$ = \
$CellContext`fixlp11$ - $CellContext`fixldx$ - $CellContext`fixldy$; \
$CellContext`fixlp13$ = $CellContext`fixlp12$ + $CellContext`fixldx$; \
$CellContext`fixlp14$ = $CellContext`fixlp13$ - $CellContext`fixldx$ - \
$CellContext`fixldy$; $CellContext`fixlp15$ = $CellContext`fixlp14$ + \
$CellContext`fixldx$; $CellContext`fixlp16$ = $CellContext`fixlp15$ - \
$CellContext`fixldx$ - $CellContext`fixldy$; $CellContext`fixrpau = \
{$CellContext`L$, $CellContext`W$}; $CellContext`fixrpad = {$CellContext`L$, \
-$CellContext`W$}; $CellContext`fixrdx = {(-$CellContext`W$)/4, 
           0}; $CellContext`fixrdy = {
          0, $CellContext`W$/
           4}; $CellContext`fixrp1 = $CellContext`fixrpau; \
$CellContext`fixrp2 = $CellContext`fixrp1 - $CellContext`fixrdx - \
$CellContext`fixrdy; $CellContext`fixrp3 = $CellContext`fixrp2 + \
$CellContext`fixrdx; $CellContext`fixrp4 = $CellContext`fixrp3 - \
$CellContext`fixrdx - $CellContext`fixrdy; $CellContext`fixrp5 = \
$CellContext`fixrp4 + $CellContext`fixrdx; $CellContext`fixrp6 = \
$CellContext`fixrp5 - $CellContext`fixrdx - $CellContext`fixrdy; \
$CellContext`fixrp7 = $CellContext`fixrp6 + $CellContext`fixrdx; \
$CellContext`fixrp8 = $CellContext`fixrp7 - $CellContext`fixrdx - \
$CellContext`fixrdy; $CellContext`fixrp9 = $CellContext`fixrp8 + \
$CellContext`fixrdx; $CellContext`fixrp10 = $CellContext`fixrp9 - \
$CellContext`fixrdx - $CellContext`fixrdy; $CellContext`fixrp11 = \
$CellContext`fixrp10 + $CellContext`fixrdx; $CellContext`fixrp12 = \
$CellContext`fixrp11 - $CellContext`fixrdx - $CellContext`fixrdy; \
$CellContext`fixrp13 = $CellContext`fixrp12 + $CellContext`fixrdx; \
$CellContext`fixrp14 = $CellContext`fixrp13 - $CellContext`fixrdx - \
$CellContext`fixrdy; $CellContext`fixrp15 = $CellContext`fixrp14 + \
$CellContext`fixrdx; $CellContext`fixrp16 = $CellContext`fixrp15 - \
$CellContext`fixrdx - $CellContext`fixrdy; $CellContext`pinlta$ = \
$CellContext`pa$; $CellContext`pinlr$ = 
         0.1 $CellContext`W$; $CellContext`pinldx$ = {$CellContext`W$/4, 
           0}; $CellContext`pinldy$ = {
          0, $CellContext`W$/4}; $CellContext`pinltb$ = $CellContext`pinlta$ - 
          2.5 $CellContext`pinldx$ - 
          3.5 $CellContext`pinldy$; $CellContext`pinltc$ = \
$CellContext`pinlta$ + 2.5 $CellContext`pinldx$ - 
          3.5 $CellContext`pinldy$; $CellContext`pinlal$ = \
$CellContext`pinltb$ - $CellContext`pinldx$; $CellContext`pinlar$ = \
$CellContext`pinltc$ + $CellContext`pinldx$; $CellContext`pinlp1$ = \
$CellContext`pinlal$ + $CellContext`pinldx$; $CellContext`pinlp2$ = \
$CellContext`pinlp1$ - $CellContext`pinldx$ - $CellContext`pinldy$; \
$CellContext`pinlp3$ = $CellContext`pinlp1$ + $CellContext`pinldx$; \
$CellContext`pinlp4$ = $CellContext`pinlp3$ - $CellContext`pinldx$ - \
$CellContext`pinldy$; $CellContext`pinlp5$ = $CellContext`pinlp3$ + \
$CellContext`pinldx$; $CellContext`pinlp6$ = $CellContext`pinlp5$ - \
$CellContext`pinldx$ - $CellContext`pinldy$; $CellContext`pinlp7$ = \
$CellContext`pinlp5$ + $CellContext`pinldx$; $CellContext`pinlp8$ = \
$CellContext`pinlp7$ - $CellContext`pinldx$ - $CellContext`pinldy$; \
$CellContext`pinlp9$ = $CellContext`pinlp7$ + $CellContext`pinldx$; \
$CellContext`pinlp10$ = $CellContext`pinlp9$ - $CellContext`pinldx$ - \
$CellContext`pinldy$; $CellContext`pinlp11$ = $CellContext`pinlp9$ + \
$CellContext`pinldx$; $CellContext`pinlp12$ = $CellContext`pinlp11$ - \
$CellContext`pinldx$ - $CellContext`pinldy$; $CellContext`pinlp13 = \
$CellContext`pinlp11$ + $CellContext`pinldx$; $CellContext`pinlp14 = \
$CellContext`pinlp13 - $CellContext`pinldx$ - $CellContext`pinldy$; \
$CellContext`pinrta = $CellContext`pe$; $CellContext`pinrr = 
         0.1 $CellContext`W$; $CellContext`pinrdx = {$CellContext`W$/4, 
           0}; $CellContext`pinrdy = {
          0, $CellContext`W$/4}; $CellContext`pinrtb = $CellContext`pinrta - 
          2.5 $CellContext`pinrdx - 
          3.5 $CellContext`pinrdy; $CellContext`pinrtc = $CellContext`pinrta + 
          2.5 $CellContext`pinrdx - 
          3.5 $CellContext`pinrdy; $CellContext`pinral = $CellContext`pinrtb - \
$CellContext`pinrdx; $CellContext`pinrar = $CellContext`pinrtc + \
$CellContext`pinrdx; $CellContext`pinrp1 = $CellContext`pinral + \
$CellContext`pinrdx; $CellContext`pinrp2 = $CellContext`pinrp1 - \
$CellContext`pinrdx - $CellContext`pinrdy; $CellContext`pinrp3 = \
$CellContext`pinrp1 + $CellContext`pinrdx; $CellContext`pinrp4 = \
$CellContext`pinrp3 - $CellContext`pinrdx - $CellContext`pinrdy; \
$CellContext`pinrp5 = $CellContext`pinrp3 + $CellContext`pinrdx; \
$CellContext`pinrp6 = $CellContext`pinrp5 - $CellContext`pinrdx - \
$CellContext`pinrdy; $CellContext`pinrp7 = $CellContext`pinrp5 + \
$CellContext`pinrdx; $CellContext`pinrp8 = $CellContext`pinrp7 - \
$CellContext`pinrdx - $CellContext`pinrdy; $CellContext`pinrp9 = \
$CellContext`pinrp7 + $CellContext`pinrdx; $CellContext`pinrp10 = \
$CellContext`pinrp9 - $CellContext`pinrdx - $CellContext`pinrdy; \
$CellContext`pinrp11 = $CellContext`pinrp9 + $CellContext`pinrdx; \
$CellContext`pinrp12 = $CellContext`pinrp11 - $CellContext`pinrdx - \
$CellContext`pinrdy; $CellContext`pinrp13 = $CellContext`pinrp11 + \
$CellContext`pinrdx; $CellContext`pinrp14 = $CellContext`pinrp13 - \
$CellContext`pinrdx - $CellContext`pinrdy; $CellContext`rolr$ = 
         0.25 $CellContext`W$; $CellContext`rolc$ = {
           0, (-$CellContext`W$)/2} + {$CellContext`rolr$, 0} + {
           0, -$CellContext`rolr$}; $CellContext`roldx$ = {$CellContext`W$/4, 
           0}; $CellContext`roldy$ = {
          0, $CellContext`W$/4}; $CellContext`rolll$ = $CellContext`rolc$ - {
          0, $CellContext`rolr$} - 
          4 $CellContext`roldx$; $CellContext`rollr$ = $CellContext`rolc$ - {
          0, $CellContext`rolr$} + 
          4 $CellContext`roldx$; $CellContext`rolp1$ = $CellContext`rolll$ + \
$CellContext`roldx$; $CellContext`rolp2$ = $CellContext`rolp1$ - \
$CellContext`roldx$ - $CellContext`roldy$; $CellContext`rolp3$ = \
$CellContext`rolp1$ + $CellContext`roldx$; $CellContext`rolp4$ = \
$CellContext`rolp3$ - $CellContext`roldx$ - $CellContext`roldy$; \
$CellContext`rolp5$ = $CellContext`rolp3$ + $CellContext`roldx$; \
$CellContext`rolp6$ = $CellContext`rolp5$ - $CellContext`roldx$ - \
$CellContext`roldy$; $CellContext`rolp7$ = $CellContext`rolp5$ + \
$CellContext`roldx$; $CellContext`rolp8$ = $CellContext`rolp7$ - \
$CellContext`roldx$ - $CellContext`roldy$; $CellContext`rolp9$ = \
$CellContext`rolp7$ + $CellContext`roldx$; $CellContext`rolp10$ = \
$CellContext`rolp9$ - $CellContext`roldx$ - $CellContext`roldy$; \
$CellContext`rolp11$ = $CellContext`rolp9$ + $CellContext`roldx$; \
$CellContext`rolp12$ = $CellContext`rolp11$ - $CellContext`roldx$ - \
$CellContext`roldy$; $CellContext`rolp13$ = $CellContext`rolp11$ + \
$CellContext`roldx$; $CellContext`rolp14$ = $CellContext`rolp13$ - \
$CellContext`roldx$ - $CellContext`roldy$; $CellContext`rolp15$ = \
$CellContext`rolp13$ + $CellContext`roldx$; $CellContext`rolp16$ = \
$CellContext`rolp15$ - $CellContext`roldx$ - $CellContext`roldy$; \
$CellContext`rorr = 
         0.25 $CellContext`W$; $CellContext`rorc = {$CellContext`L$, \
(-$CellContext`W$)/2} + {-$CellContext`rorr, 0} + {
           0, -$CellContext`rorr}; $CellContext`rordx = {$CellContext`W$/4, 
           0}; $CellContext`rordy = {
          0, $CellContext`W$/4}; $CellContext`rolrl = $CellContext`rorc - {
          0, $CellContext`rorr} - 
          4 $CellContext`rordx; $CellContext`rolrr = $CellContext`rorc - {
          0, $CellContext`rorr} + 
          4 $CellContext`rordx; $CellContext`rorp1 = $CellContext`rolrl + \
$CellContext`rordx; $CellContext`rorp2 = $CellContext`rorp1 - \
$CellContext`rordx - $CellContext`rordy; $CellContext`rorp3 = \
$CellContext`rorp1 + $CellContext`rordx; $CellContext`rorp4 = \
$CellContext`rorp3 - $CellContext`rordx - $CellContext`rordy; \
$CellContext`rorp5 = $CellContext`rorp3 + $CellContext`rordx; \
$CellContext`rorp6 = $CellContext`rorp5 - $CellContext`rordx - \
$CellContext`rordy; $CellContext`rorp7 = $CellContext`rorp5 + \
$CellContext`rordx; $CellContext`rorp8 = $CellContext`rorp7 - \
$CellContext`rordx - $CellContext`rordy; $CellContext`rorp9 = \
$CellContext`rorp7 + $CellContext`rordx; $CellContext`rorp10 = \
$CellContext`rorp9 - $CellContext`rordx - $CellContext`rordy; \
$CellContext`rorp11 = $CellContext`rorp9 + $CellContext`rordx; \
$CellContext`rorp12 = $CellContext`rorp11 - $CellContext`rordx - \
$CellContext`rordy; $CellContext`rorp13 = $CellContext`rorp11 + \
$CellContext`rordx; $CellContext`rorp14 = $CellContext`rorp13 - \
$CellContext`rordx - $CellContext`rordy; $CellContext`rorp15 = \
$CellContext`rorp13 + $CellContext`rordx; $CellContext`rorp16 = \
$CellContext`rorp15 - $CellContext`rordx - $CellContext`rordy; 
        If[$CellContext`opa2$$ == 1, $CellContext`opaf2$ = 
          1, $CellContext`opaf2$ = 0]; 
        If[$CellContext`opa2$$ == -1, $CellContext`opar2$ = 
          1, $CellContext`opar2$ = 0]; 
        If[$CellContext`opa2$$ == 0, $CellContext`opap2$ = 
          1, $CellContext`opap2$ = 0]; 
        If[$CellContext`opa3$$ == 1, $CellContext`opaf3 = 
          1, $CellContext`opaf3 = 0]; 
        If[$CellContext`opa3$$ == -1, $CellContext`opar3 = 
          1, $CellContext`opar3 = 0]; 
        If[$CellContext`opa3$$ == 0, $CellContext`opap3 = 
          1, $CellContext`opap3 = 
          0]; $CellContext`fe = {$CellContext`pf$$ $CellContext`L$, 
           0}; $CellContext`fi = $CellContext`fe + {$CellContext`mf$$ 
            Cos[$CellContext`alfa$], $CellContext`mf$$ 
            Sin[$CellContext`alfa$]}; $CellContext`fx = {
          Part[$CellContext`fe, 1] - Part[$CellContext`fi, 1], 
           0}; $CellContext`fy = {
          0, Part[$CellContext`fe, 2] - Part[$CellContext`fi, 2]}; 
        If[Part[$CellContext`fy, 2] > 
          0, $CellContext`arrowa = $CellContext`pa$ + {
            0, 7 $CellContext`W$}, $CellContext`arrowa = $CellContext`pa$ + {
            0, (-5) $CellContext`W$}]; 
        If[Part[$CellContext`fy, 2] > 
          0, $CellContext`arrowb = $CellContext`pe$ + {
            0, 7 $CellContext`W$}, $CellContext`arrowb = $CellContext`pe$ + {
            0, (-5) $CellContext`W$}]; 
        If[Part[$CellContext`fy, 2] > 
          0, $CellContext`arrowfa = $CellContext`pa$ + {
            0, 5 $CellContext`W$}, $CellContext`arrowfa = $CellContext`pa$ + {
            0, (-3) $CellContext`W$}]; 
        If[Part[$CellContext`fy, 2] > 
          0, $CellContext`arrowfp = $CellContext`fe + {
            0, 5 $CellContext`W$}, $CellContext`arrowfp = $CellContext`fe + {
            0, (-3) $CellContext`W$}]; $CellContext`mp = {$CellContext`pm$$ \
$CellContext`L$, 0}; $CellContext`sitaie = (($CellContext`mm$$/4) 1.5) Pi; 
        If[$CellContext`opa4$$ > 
          0, $CellContext`sitai = (-$CellContext`sitaie)/
           2, $CellContext`sitai = $CellContext`sitaie/2]; 
        If[$CellContext`opa4$$ > 
          0, $CellContext`sitae = $CellContext`sitaie/
           2, $CellContext`sitae = (-$CellContext`sitaie)/2]; $CellContext`rm = 
         0.5; If[$CellContext`opa4$$ > 
          0, $CellContext`mi = {$CellContext`rm 
             Cos[$CellContext`sitae + 
               Abs[$CellContext`sitae - $CellContext`sitai] 
                0.1], $CellContext`rm 
             Sin[$CellContext`sitae + 
               Abs[$CellContext`sitae - $CellContext`sitai] 
                0.1]} + $CellContext`mp, $CellContext`mi = {$CellContext`rm 
             Cos[$CellContext`sitae - 
               Abs[$CellContext`sitae - $CellContext`sitai] 
               0.1], $CellContext`rm 
             Sin[$CellContext`sitae - 
               Abs[$CellContext`sitae - $CellContext`sitai] 
               0.1]} + $CellContext`mp]; $CellContext`me = {$CellContext`rm 
            Cos[$CellContext`sitae], $CellContext`rm 
            Sin[$CellContext`sitae]} + $CellContext`mp; If[
          
          And[$CellContext`opa2$$ == 1, $CellContext`opa3$$ == 
           1], $CellContext`ffbeam = 1, $CellContext`ffbeam = 0]; If[
          
          And[$CellContext`opa2$$ == 1, $CellContext`opa3$$ == 
           0], $CellContext`fpbeam = 1, $CellContext`fpbeam = 0]; If[
          
          And[$CellContext`opa2$$ == 
           1, $CellContext`opa3$$ == -1], $CellContext`frbeam = 
          1, $CellContext`frbeam = 0]; If[
          
          And[$CellContext`opa2$$ == 
           1, $CellContext`opa3$$ == -2], $CellContext`fnbeam = 
          1, $CellContext`fnbeam = 0]; If[
          
          And[$CellContext`opa2$$ == 0, $CellContext`opa3$$ == 
           0], $CellContext`ppbeam = 1, $CellContext`ppbeam = 0]; If[
          
          And[$CellContext`opa2$$ == 
           0, $CellContext`opa3$$ == -1], $CellContext`prbeam = 
          1, $CellContext`prbeam = 0]; If[
          
          And[$CellContext`opa2$$ == -1, $CellContext`opa3$$ == -1], \
$CellContext`rrbeam = 1, $CellContext`rrbeam = 0]; $CellContext`rfaffx = {
          0.25 $CellContext`L$, 0}; $CellContext`rfaffy = {
          0, 
           0.25 $CellContext`L$}; $CellContext`rfbffx = $CellContext`rfaffx; \
$CellContext`rfbffy = $CellContext`rfaffy; $CellContext`sitaffai = 
         Pi - Pi/3; $CellContext`sitaffae = 
         Pi + Pi/3; $CellContext`rmaff = $CellContext`rm; $CellContext`maffi = \
{$CellContext`rmaff 
            Cos[$CellContext`sitaffae + 
              Abs[$CellContext`sitaffae - $CellContext`sitaffai] 
               0.1], $CellContext`rmaff 
            Sin[$CellContext`sitaffae + 
              Abs[$CellContext`sitaffae - $CellContext`sitaffai] 
               0.1]} + $CellContext`pa$; $CellContext`maffe = \
{$CellContext`rmaff Cos[$CellContext`sitaffae], $CellContext`rmaff 
            Sin[$CellContext`sitaffae]} + $CellContext`pa$; \
$CellContext`sitaffbi = (-Pi)/3; $CellContext`sitaffbe = 
         Pi/3; $CellContext`rmbff = $CellContext`rm; $CellContext`mbffi = \
{$CellContext`rmbff 
            Cos[$CellContext`sitaffbe + 
              Abs[$CellContext`sitaffbe - $CellContext`sitaffbi] 
               0.1], $CellContext`rmbff 
            Sin[$CellContext`sitaffbe + 
              Abs[$CellContext`sitaffbe - $CellContext`sitaffbi] 
               0.1]} + $CellContext`pe$; $CellContext`mbffe = \
{$CellContext`rmbff Cos[$CellContext`sitaffbe], $CellContext`rmbff 
            Sin[$CellContext`sitaffbe]} + $CellContext`pe$; \
$CellContext`rfafpx = {0.25 $CellContext`L$, 0}; $CellContext`rfafpy = {
          0, 0.25 $CellContext`L$}; $CellContext`rfbfpx = $CellContext`rfaffx; \
$CellContext`rfbfpy = $CellContext`rfaffy; $CellContext`sitafpai = 
         Pi - Pi/3; $CellContext`sitafpae = 
         Pi + Pi/3; $CellContext`rmafp = $CellContext`rm; $CellContext`mafpi = \
{$CellContext`rmafp 
            Cos[$CellContext`sitafpae + 
              Abs[$CellContext`sitafpae - $CellContext`sitafpai] 
               0.1], $CellContext`rmafp 
            Sin[$CellContext`sitafpae + 
              Abs[$CellContext`sitafpae - $CellContext`sitafpai] 
               0.1]} + $CellContext`pa$; $CellContext`mafpe = \
{$CellContext`rmafp Cos[$CellContext`sitafpae], $CellContext`rmafp 
            Sin[$CellContext`sitafpae]} + $CellContext`pa$; \
$CellContext`rfafrx = {0.25 $CellContext`L$, 0}; $CellContext`rfafry = {
          0, 0.25 $CellContext`L$}; $CellContext`rfbfry = $CellContext`rfaffy; \
$CellContext`sitafrai = Pi - Pi/3; $CellContext`sitafrae = 
         Pi + Pi/3; $CellContext`rmafr = $CellContext`rm; $CellContext`mafri = \
{$CellContext`rmafr 
            Cos[$CellContext`sitafrae + 
              Abs[$CellContext`sitafrae - $CellContext`sitafrai] 
               0.1], $CellContext`rmafr 
            Sin[$CellContext`sitafrae + 
              Abs[$CellContext`sitafrae - $CellContext`sitafrai] 
               0.1]} + $CellContext`pa$; $CellContext`mafre = \
{$CellContext`rmafr Cos[$CellContext`sitafrae], $CellContext`rmafr 
            Sin[$CellContext`sitafrae]} + $CellContext`pa$; \
$CellContext`rfafnx = -$CellContext`fx; $CellContext`rfafny = \
-$CellContext`fy; 
        If[$CellContext`opa4$$ == 
          1, $CellContext`mmam = -$CellContext`mm$$, $CellContext`mmam = \
$CellContext`mm$$]; $CellContext`mmaf = ((-
            Part[$CellContext`fy, 
              2]) $CellContext`pf$$) $CellContext`L$; $CellContext`mma = \
$CellContext`mmam + $CellContext`mmaf; $CellContext`sitafnie = ((
            Abs[$CellContext`mma]/4) 1.5) Pi; 
        If[$CellContext`mma > 0, $CellContext`sitafnai = 
          Pi - $CellContext`sitafnie/2, $CellContext`sitafnai = 
          Pi + $CellContext`sitafnie/2]; 
        If[$CellContext`mma > 0, $CellContext`sitafnae = 
          Pi + $CellContext`sitafnie/2, $CellContext`sitafnae = 
          Pi - $CellContext`sitafnie/2]; $CellContext`rmafn = $CellContext`rm; 
        If[$CellContext`mma > 
          0, $CellContext`mafni = {$CellContext`rmafn 
             Cos[$CellContext`sitafnae - $CellContext`sitafnie 
               0.1], $CellContext`rmafn 
             Sin[$CellContext`sitafnae - $CellContext`sitafnie 
               0.1]} + $CellContext`pa$, $CellContext`mafni = \
{$CellContext`rmafn 
             Cos[$CellContext`sitafnae + $CellContext`sitafnie 
                0.1], $CellContext`rmafn 
             Sin[$CellContext`sitafnae + $CellContext`sitafnie 
                0.1]} + $CellContext`pa$]; $CellContext`mafne = \
{$CellContext`rmafn Cos[$CellContext`sitafnae], $CellContext`rmafn 
            Sin[$CellContext`sitafnae]} + $CellContext`pa$; \
$CellContext`rfappx = {0.25 $CellContext`L$, 0}; $CellContext`rfappy = {
          0, 0.25 $CellContext`L$}; $CellContext`rfbppx = $CellContext`rfappx; \
$CellContext`rfbppy = $CellContext`rfaffy; $CellContext`rfaprx = \
-$CellContext`fx; 
        If[$CellContext`opa4$$ > 
          0, $CellContext`rfbpry = {
           0, -(Part[$CellContext`fy, 
                2] $CellContext`pf$$ + $CellContext`mm$$)}, \
$CellContext`rfbpry = {
           0, -(Part[$CellContext`fy, 
                2] $CellContext`pf$$ - $CellContext`mm$$)}]; \
$CellContext`rfapry = -$CellContext`rfbpry - $CellContext`fy; 
        If[$CellContext`opa4$$ > 
          0, $CellContext`rfbrry = {
           0, -(Part[$CellContext`fy, 
                2] $CellContext`pf$$ + $CellContext`mm$$)}, \
$CellContext`rfbrry = {
           0, -(Part[$CellContext`fy, 
                2] $CellContext`pf$$ - $CellContext`mm$$)}]; \
$CellContext`rfarry = -$CellContext`rfbrry - $CellContext`fy; 
        If[$CellContext`ffbeam == 1, $CellContext`temp1 = Row[{
             Spacer[0], 
             "\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[\"M\", \n   RowBox[{\"@\", \"A\"}]],\n  \
TraditionalForm],\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 0.]]\)\!\(\*\nStyleBox[\"0\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"M\", \"A\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[SubscriptBox[\"M\", \"B\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"+\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[SubscriptBox[\"F\", \"y\"],\nFontWeight->\"Plain\"]\)\!\(\*\n\
StyleBox[\"\[Times]\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*SubscriptBox[\(L\), \(f\)]\)\!\(\*\nStyleBox[\"+\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[SubscriptBox[\"B\", \"y\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Times]\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)L\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[\"M\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"0\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)", ";"}]]; 
        If[$CellContext`fpbeam == 1, $CellContext`temp1 = Row[{
             Spacer[0], 
             "\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[\"M\", \n   RowBox[{\"@\", \"A\"}]],\n  \
TraditionalForm],\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 0.]]\)\!\(\*\nStyleBox[\"0\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"M\", \"A\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[SubscriptBox[\"F\", \"y\"],\nFontWeight->\"Plain\"]\)\!\(\*\n\
StyleBox[\"\[Times]\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*SubscriptBox[\(L\), \(f\)]\)\!\(\*\nStyleBox[\"+\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[SubscriptBox[\"B\", \"y\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"\[Times]\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)L\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[\"M\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"0\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)", ";"}]]; 
        If[$CellContext`frbeam == 1, $CellContext`temp1 = Row[{
             Spacer[0], 
             "\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[\"M\", \n   RowBox[{\"@\", \"A\"}]],\n  \
TraditionalForm],\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 0.]]\)\!\(\*\nStyleBox[\"0\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"M\", \"A\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[SubscriptBox[\"F\", \"y\"],\nFontWeight->\"Plain\"]\)\!\(\*\n\
StyleBox[\"\[Times]\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*SubscriptBox[\(L\), \(f\)]\)\!\(\*\nStyleBox[\"+\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"M\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)", ";"}]]; If[$CellContext`fnbeam == 1, $CellContext`temp1 = Row[{
             Spacer[0], 
             "\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[\"M\", \n   RowBox[{\"@\", \"A\"}]],\n  \
TraditionalForm],\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 0.]]\)\!\(\*\nStyleBox[\"0\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"M\", \"A\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[SubscriptBox[\"F\", \"y\"],\nFontWeight->\"Plain\"]\)\!\(\*\n\
StyleBox[\"\[Times]\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*SubscriptBox[\(L\), \(f\)]\)\!\(\*\nStyleBox[\"+\",\nFontWeight->\
\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"M\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)", ";"}]]; If[$CellContext`ppbeam == 1, $CellContext`temp1 = Row[{
             Spacer[0], 
             "\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[\"M\", \n   RowBox[{\"@\", \"A\"}]],\n  \
TraditionalForm],\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 0.]]\)\!\(\*\nStyleBox[\"0\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"F\", \"y\"],\n\
FontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\"\[Times]\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*SubscriptBox[\
\(L\), \(f\)]\)\!\(\*\nStyleBox[\"+\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[SubscriptBox[\"B\", \
\"y\"],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"\[Times]\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)L\!\(\*\nStyleBox[\"+\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"M\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)", ";"}]]; If[$CellContext`prbeam == 1, $CellContext`temp1 = Row[{
             Spacer[0], 
             "\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[\"M\", \n   RowBox[{\"@\", \"A\"}]],\n  \
TraditionalForm],\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 0.]]\)\!\(\*\nStyleBox[\"0\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"F\", \"y\"],\n\
FontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\"\[Times]\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*SubscriptBox[\
\(L\), \(f\)]\)\!\(\*\nStyleBox[\"+\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[SubscriptBox[\"B\", \
\"y\"],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"\[Times]\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)L\!\(\*\nStyleBox[\"+\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"M\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)", ";"}]]; If[$CellContext`rrbeam == 1, $CellContext`temp1 = Row[{
             Spacer[0], 
             "\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[\"M\", \n   RowBox[{\"@\", \"A\"}]],\n  \
TraditionalForm],\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 0.]]\)\!\(\*\nStyleBox[\"0\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"F\", \"y\"],\n\
FontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\"\[Times]\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*SubscriptBox[\
\(L\), \(f\)]\)\!\(\*\nStyleBox[\"+\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[SubscriptBox[\"B\", \
\"y\"],\nFontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"\[Times]\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)L\!\(\*\nStyleBox[\"+\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"M\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)", ";"}]]; 
        If[$CellContext`ffbeam == 1, $CellContext`temp2 = 
          Row[{"\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[SubscriptBox[\"F\", \"x\"], \n   RowBox[{\"@\", \
\"A\"}]],\n  TraditionalForm],\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"0\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"A\", \"x\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[SubscriptBox[\"B\", \"x\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"+\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[SubscriptBox[\"F\", \"x\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             ";"}]]; If[$CellContext`fpbeam == 1, $CellContext`temp2 = 
          Row[{"\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[SubscriptBox[\"F\", \"x\"], \n   RowBox[{\"@\", \
\"A\"}]],\n  TraditionalForm],\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"0\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"A\", \"x\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[SubscriptBox[\"B\", \"x\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"+\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[SubscriptBox[\"F\", \"x\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             ";"}]]; If[$CellContext`frbeam == 1, $CellContext`temp2 = 
          Row[{"\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[SubscriptBox[\"F\", \"x\"], \n   RowBox[{\"@\", \
\"A\"}]],\n  TraditionalForm],\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"0\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"A\", \"x\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[SubscriptBox[\"F\", \"x\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             ";"}]]; If[$CellContext`fnbeam == 1, $CellContext`temp2 = 
          Row[{"\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[SubscriptBox[\"F\", \"x\"], \n   RowBox[{\"@\", \
\"A\"}]],\n  TraditionalForm],\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"0\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"A\", \"x\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[SubscriptBox[\"F\", \"x\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             ";"}]]; If[$CellContext`ppbeam == 1, $CellContext`temp2 = 
          Row[{"\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[SubscriptBox[\"F\", \"x\"], \n   RowBox[{\"@\", \
\"A\"}]],\n  TraditionalForm],\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"0\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"A\", \"x\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[SubscriptBox[\"B\", \"x\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"+\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[SubscriptBox[\"F\", \"x\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             ";"}]]; If[$CellContext`prbeam == 1, $CellContext`temp2 = 
          Row[{"\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[SubscriptBox[\"F\", \"x\"], \n   RowBox[{\"@\", \
\"A\"}]],\n  TraditionalForm],\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"0\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"A\", \"x\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[SubscriptBox[\"F\", \"x\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             ";"}]]; If[$CellContext`rrbeam == 1, $CellContext`temp2 = 
          Row[{"\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[SubscriptBox[\"F\", \"x\"], \n   RowBox[{\"@\", \
\"A\"}]],\n  TraditionalForm],\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"0\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"F\", \"x\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[\"ma\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)", ";"}]]; 
        If[$CellContext`fnbeam == 1, $CellContext`temp3 = 
          Row[{
            "\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[SubscriptBox[\"F\", \"y\"], \n   RowBox[{\"@\", \
\"A\"}]],\n  TraditionalForm],\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"0\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"A\", \"y\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[SubscriptBox[\"F\", \"y\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             "."}], $CellContext`temp3 = 
          Row[{"\!\(\*\nStyleBox[\"\[Sum]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[FormBox[SubscriptBox[SubscriptBox[\"F\", \"y\"], \n   RowBox[{\"@\", \
\"A\"}]],\n  TraditionalForm],\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"0\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\":\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[SubscriptBox[\"A\", \"y\"],\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"+\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\
\(\*\nStyleBox[SubscriptBox[\"B\", \"y\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"+\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[SubscriptBox[\"F\", \"y\"],\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"=\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"0\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             "."}]]; If[$CellContext`ffbeam == 1, $CellContext`temp4 = 
          Row[{"\!\(\*\nStyleBox[\"#\",\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Reactive\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"forces\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"/\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\
\(\*\nStyleBox[\"moments\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[\"6\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`fpbeam == 1, $CellContext`temp4 = 
          Row[{"\!\(\*\nStyleBox[\"#\",\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Reactive\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"forces\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"/\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\
\(\*\nStyleBox[\"moments\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[\"5\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`frbeam == 1, $CellContext`temp4 = 
          Row[{"\!\(\*\nStyleBox[\"#\",\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Reactive\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"forces\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"/\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\
\(\*\nStyleBox[\"moments\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[\"4\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`fnbeam == 1, $CellContext`temp4 = 
          Row[{"\!\(\*\nStyleBox[\"#\",\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Reactive\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"forces\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"/\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\
\(\*\nStyleBox[\"moments\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[\"3\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`ppbeam == 1, $CellContext`temp4 = 
          Row[{"\!\(\*\nStyleBox[\"#\",\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Reactive\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"forces\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"/\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\
\(\*\nStyleBox[\"moments\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[\"4\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`prbeam == 1, $CellContext`temp4 = 
          Row[{"\!\(\*\nStyleBox[\"#\",\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Reactive\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"forces\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"/\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\
\(\*\nStyleBox[\"moments\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[\"3\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`rrbeam == 1, $CellContext`temp4 = 
          Row[{"\!\(\*\nStyleBox[\"#\",\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Reactive\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"forces\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"/\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\
\(\*\nStyleBox[\"moments\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[5], 
             "\!\(\*\nStyleBox[\"2\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", "."}]]; $CellContext`temp5 = 
         Row[{"\!\(\*\nStyleBox[\"#\",\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Equations\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"of\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Equilibrium\",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", 
            Spacer[5], 
            "\!\(\*\nStyleBox[\"3\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)", "."}]; 
        If[$CellContext`ffbeam == 1, $CellContext`temp6 = 
          Row[{"\!\(\*\nStyleBox[\"Status\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\":\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[10], 
             "\!\(\*\nStyleBox[\"Statically\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"indeterminate\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`fpbeam == 1, $CellContext`temp6 = 
          Row[{"\!\(\*\nStyleBox[\"Status\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\":\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[10], 
             "\!\(\*\nStyleBox[\"Statically\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"indeterminate\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`frbeam == 1, $CellContext`temp6 = 
          Row[{"\!\(\*\nStyleBox[\"Status\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\":\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[10], 
             "\!\(\*\nStyleBox[\"Statically\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"indeterminate\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`fnbeam == 1, $CellContext`temp6 = 
          Row[{"\!\(\*\nStyleBox[\"Status\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\":\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[10], 
             "\!\(\*\nStyleBox[\"Statically\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"determinate\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`ppbeam == 1, $CellContext`temp6 = 
          Row[{"\!\(\*\nStyleBox[\"Status\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\":\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[10], 
             "\!\(\*\nStyleBox[\"Statically\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"indeterminate\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`prbeam == 1, $CellContext`temp6 = 
          Row[{
            "\!\(\*\nStyleBox[\"Status\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\":\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[10], 
             "\!\(\*\nStyleBox[\"Statically\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"determinate\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`rrbeam == 1, $CellContext`temp6 = 
          Row[{"\!\(\*\nStyleBox[\"Status\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\":\",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             Spacer[10], 
             "\!\(\*\nStyleBox[\"Statically\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"unstable\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", "."}]]; 
        If[$CellContext`fnbeam == 1, $CellContext`temp7 = 
          Row[{"\!\(\*\nStyleBox[FormBox[SubscriptBox[\"M\", \"A\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\
\!\(\*\nStyleBox[\"  \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
             NumberForm[$CellContext`mma, {3, 2}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"\[CenterDot]\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"m\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"x\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 1.]]\)", 
             NumberForm[
              Part[$CellContext`rfafnx, 1], {3, 2}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"y\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\) ", 
             NumberForm[
              Part[$CellContext`rfafny, 2], {3, 2}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}]]; 
        If[$CellContext`prbeam == 1, $CellContext`temp7 = 
          Row[{"\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"x\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Plain\",\nFontColor->RGBColor[1., 0., 1.]]\)", 
             NumberForm[
              Part[$CellContext`rfaprx, 1], {3, 2}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"A\", \"y\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\) ", 
             NumberForm[
              Part[$CellContext`rfapry, 2], {3, 2}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
             Spacer[15], 
             "\!\(\*\nStyleBox[FormBox[SubscriptBox[\"B\", \"y\"],\n  \
TraditionalForm],\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., 0.]]\)\
\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\",\nFontColor->RGBColor[0., 0., \
0.]]\)\!\(\*\nStyleBox[\"=\",\nFontWeight->\"Plain\",\n\
FontColor->RGBColor[0., 0., 0.]]\) ", 
             NumberForm[
              Part[$CellContext`rfbpry, 2], {3, 2}], 
             Spacer[2], 
             "\!\(\*\nStyleBox[\"kN\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}]]; $CellContext`dwf0$ = {
           Opacity[$CellContext`opa1$$], 
           Dashing[{}], 
           Thickness[0.001], 
           Arrowheads[0.02], 
           Arrow[{{-$CellContext`size$, 0}, {1.15 $CellContext`size$, 0}}], 
           
           Arrow[{{0, (-0.45) $CellContext`size$}, {
             0, 0.45 $CellContext`size$}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {1.2 $CellContext`size$, 0}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$, 
             0.45 $CellContext`size$}]}; $CellContext`dwf1$ = {
           Opacity[0.5], Blue, 
           
           Rectangle[{
            0, (-0.5) $CellContext`W$}, {$CellContext`L$, 
             0.5 $CellContext`W$}]}; $CellContext`dwf2$ = {
           Opacity[$CellContext`opaf2$ (1 - $CellContext`opa5$$)], 
           Thickness[0.005], 
           Line[{$CellContext`fixlpau$, $CellContext`fixlpad$}], 
           Line[{$CellContext`fixlp1$, $CellContext`fixlp2$}], 
           Line[{$CellContext`fixlp3$, $CellContext`fixlp4$}], 
           Line[{$CellContext`fixlp5$, $CellContext`fixlp6$}], 
           Line[{$CellContext`fixlp7$, $CellContext`fixlp8$}], 
           Line[{$CellContext`fixlp9$, $CellContext`fixlp10$}], 
           Line[{$CellContext`fixlp11$, $CellContext`fixlp12$}], 
           Line[{$CellContext`fixlp13$, $CellContext`fixlp14$}], 
           
           Line[{$CellContext`fixlp15$, $CellContext`fixlp16$}]}; \
$CellContext`dwf3$ = {
           Opacity[$CellContext`opap2$ (1 - $CellContext`opa5$$)], 
           Thickness[0.005], 
           Darker[Green], 
           
           Triangle[{$CellContext`pinlta$, $CellContext`pinltb$, \
$CellContext`pinltc$}], 
           Thickness[0.012], 
           Circle[$CellContext`pa$, $CellContext`pinlr$], 
           Thickness[0.005], 
           Line[{$CellContext`pinlal$, $CellContext`pinlar$}], 
           Line[{$CellContext`pinlp1$, $CellContext`pinlp2$}], 
           Line[{$CellContext`pinlp3$, $CellContext`pinlp4$}], 
           Line[{$CellContext`pinlp5$, $CellContext`pinlp6$}], 
           Line[{$CellContext`pinlp7$, $CellContext`pinlp8$}], 
           Line[{$CellContext`pinlp9$, $CellContext`pinlp10$}], 
           Line[{$CellContext`pinlp11$, $CellContext`pinlp12$}], 
           
           Line[{$CellContext`pinlp13, $CellContext`pinlp14}]}; \
$CellContext`dwf4$ = {
           Opacity[$CellContext`opar2$ (1 - $CellContext`opa5$$)], 
           Thickness[0.005], 
           Darker[Blue], 
           Circle[$CellContext`rolc$, $CellContext`rolr$], 
           Thickness[0.005], 
           Line[{$CellContext`rolll$, $CellContext`rollr$}], 
           Line[{$CellContext`rolp1$, $CellContext`rolp2$}], 
           Line[{$CellContext`rolp3$, $CellContext`rolp4$}], 
           Line[{$CellContext`rolp5$, $CellContext`rolp6$}], 
           Line[{$CellContext`rolp7$, $CellContext`rolp8$}], 
           Line[{$CellContext`rolp9$, $CellContext`rolp10$}], 
           Line[{$CellContext`rolp11$, $CellContext`rolp12$}], 
           Line[{$CellContext`rolp13$, $CellContext`rolp14$}], 
           
           Line[{$CellContext`rolp15$, $CellContext`rolp16$}]}; \
$CellContext`dwf5$ = {
           Opacity[$CellContext`opaf3 (1 - $CellContext`opa5$$)], 
           Thickness[0.005], 
           Line[{$CellContext`fixrpau, $CellContext`fixrpad}], 
           Line[{$CellContext`fixrp1, $CellContext`fixrp2}], 
           Line[{$CellContext`fixrp3, $CellContext`fixrp4}], 
           Line[{$CellContext`fixrp5, $CellContext`fixrp6}], 
           Line[{$CellContext`fixrp7, $CellContext`fixrp8}], 
           Line[{$CellContext`fixrp9, $CellContext`fixrp10}], 
           Line[{$CellContext`fixrp11, $CellContext`fixrp12}], 
           Line[{$CellContext`fixrp13, $CellContext`fixrp14}], 
           
           Line[{$CellContext`fixrp15, $CellContext`fixrp16}]}; \
$CellContext`dwf6$ = {
           Opacity[$CellContext`opap3 (1 - $CellContext`opa5$$)], 
           Thickness[0.005], 
           Darker[Green], 
           
           Triangle[{$CellContext`pinrta, $CellContext`pinrtb, \
$CellContext`pinrtc}], 
           Thickness[0.012], 
           Circle[$CellContext`pe$, $CellContext`pinrr], 
           Thickness[0.005], 
           Line[{$CellContext`pinral, $CellContext`pinrar}], 
           Line[{$CellContext`pinrp1, $CellContext`pinrp2}], 
           Line[{$CellContext`pinrp3, $CellContext`pinrp4}], 
           Line[{$CellContext`pinrp5, $CellContext`pinrp6}], 
           Line[{$CellContext`pinrp7, $CellContext`pinrp8}], 
           Line[{$CellContext`pinrp9, $CellContext`pinrp10}], 
           Line[{$CellContext`pinrp11, $CellContext`pinrp12}], 
           
           Line[{$CellContext`pinrp13, $CellContext`pinrp14}]}; \
$CellContext`dwf7$ = {
           Opacity[$CellContext`opar3 (1 - $CellContext`opa5$$)], 
           Thickness[0.005], 
           Darker[Blue], 
           Circle[$CellContext`rorc, $CellContext`rorr], 
           Thickness[0.005], 
           Line[{$CellContext`rolrl, $CellContext`rolrr}], 
           Line[{$CellContext`rorp1, $CellContext`rorp2}], 
           Line[{$CellContext`rorp3, $CellContext`rorp4}], 
           Line[{$CellContext`rorp5, $CellContext`rorp6}], 
           Line[{$CellContext`rorp7, $CellContext`rorp8}], 
           Line[{$CellContext`rorp9, $CellContext`rorp10}], 
           Line[{$CellContext`rorp11, $CellContext`rorp12}], 
           Line[{$CellContext`rorp13, $CellContext`rorp14}], 
           
           Line[{$CellContext`rorp15, $CellContext`rorp16}]}; \
$CellContext`dwf8$ = {
           Opacity[1 - $CellContext`opa5$$], 
           Thickness[0.005], 
           Arrowheads[0.03], 
           Arrow[{$CellContext`fi, $CellContext`fe}], 
           If[Norm[$CellContext`fe - $CellContext`fi] > 0, 
            Text["F", $CellContext`fi + {0.15, 0.15}]], Dashed, 
           Thickness[0.004], 
           
           Line[{{$CellContext`W$/4, 0}, {$CellContext`L$ - $CellContext`W$/4,
               0}}], 
           PointSize[0.02], 
           Point[$CellContext`fe], Black, 
           Text[
           "A", $CellContext`pa$ + {0.3 $CellContext`W$, $CellContext`W$}], 
           Text[
           "B", $CellContext`pe$ + {(-0.3) $CellContext`W$, \
$CellContext`W$}]}; $CellContext`dwf9$ = {
           Opacity[1], 
           Thickness[0.005], 
           PointSize[0.02], 
           Point[$CellContext`mp], 
           Arrowheads[0.03], 
           Arrow[{$CellContext`me, $CellContext`mi}], 
           
           Circle[$CellContext`mp, $CellContext`rm, {$CellContext`sitai, \
$CellContext`sitae}], 
           If[$CellContext`mm$$ > 0, 
            If[$CellContext`opa4$$ > 0, 
             Text[
             "M", $CellContext`me + {
               0.5 $CellContext`W$, 0.5 $CellContext`W$}], 
             Text[
             "M", $CellContext`me + {
               0.5 $CellContext`W$, (-0.5) $CellContext`W$}]]]}; \
$CellContext`dwf10$ = {
           Opacity[$CellContext`opa5$$], 
           Thickness[0.005], 
           Arrowheads[0.03], 
           Line[{$CellContext`fi + $CellContext`fy, $CellContext`fe}], 
           Line[{$CellContext`fi + $CellContext`fx, $CellContext`fe}], 
           Dashing[0.005], 
           Arrow[{$CellContext`fi, $CellContext`fe}], 
           Line[{$CellContext`fi, $CellContext`fx + $CellContext`fi}], 
           Line[{$CellContext`fi, $CellContext`fy + $CellContext`fi}], 
           Arrow[{$CellContext`fi + $CellContext`fx, $CellContext`fe}], 
           Arrow[{$CellContext`fi + $CellContext`fy, $CellContext`fe}], 
           If[Part[$CellContext`fx, 1] > 0, 
            Text[
            "\!\(\*SubscriptBox[\(F\), \(y\)]\)", $CellContext`fi + \
$CellContext`fx + {0.25, 0}], 
            Text[
            "\!\(\*SubscriptBox[\(F\), \(y\)]\)", $CellContext`fi + \
$CellContext`fx + {-0.25, 0}]], 
           If[Part[$CellContext`fy, 2] > 0, 
            Text[
            "\!\(\*SubscriptBox[\(F\), \(x\)]\)", $CellContext`fi + \
$CellContext`fy + {0, 0.25}], 
            Text[
            "\!\(\*SubscriptBox[\(F\), \(x\)]\)", $CellContext`fi + \
$CellContext`fy + {0, -0.25}]], 
           Thickness[0.004], 
           Line[{$CellContext`pa$, $CellContext`pe$}], Blue, 
           Dashing[1], 
           Arrow[{$CellContext`arrowa, $CellContext`arrowb}], 
           Arrow[{$CellContext`arrowb, $CellContext`arrowa}], 
           If[Part[$CellContext`fy, 2] > 0, 
            Text[
            "\!\(\*\nStyleBox[\"L\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", ($CellContext`arrowa + $CellContext`arrowb)/2 + {
              0, 0.3}], 
            Text[
            "\!\(\*\nStyleBox[\"L\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", ($CellContext`arrowa + $CellContext`arrowb)/2 + {
              0, -0.3}]], 
           If[Part[$CellContext`fy, 2] > 0, 
            Text[
            "\!\(\*\nStyleBox[SubscriptBox[\"L\", \"f\"],\nFontWeight->\"Bold\
\",\nFontSlant->\"Italic\"]\)", ($CellContext`arrowfa + $CellContext`arrowfp)/
              2 + {0, 0.25}], 
            Text[
            "\!\(\*\nStyleBox[SubscriptBox[\"L\", \"f\"],\nFontWeight->\"Bold\
\",\nFontSlant->\"Italic\"]\)", ($CellContext`arrowfa + $CellContext`arrowfp)/
              2 + {0, -0.25}]], 
           Arrow[{$CellContext`arrowfa, $CellContext`arrowfp}], 
           Arrow[{$CellContext`arrowfp, $CellContext`arrowfa}], 
           Dashing[0.005], 
           Line[{$CellContext`pa$, $CellContext`arrowa}], 
           Line[{$CellContext`pe$, $CellContext`arrowb}], 
           
           Line[{$CellContext`fe, $CellContext`arrowfp}]}; \
$CellContext`dwf11$ = {
           Opacity[$CellContext`opa5$$ $CellContext`ffbeam], 
           Thickness[0.005], 
           Arrowheads[0.03], Red, 
           Arrow[{$CellContext`pa$ - $CellContext`rfaffx, $CellContext`pa$}], 
           Text[
           "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ - \
$CellContext`rfaffx + {0.2, 0.2}], 
           Arrow[{$CellContext`pe$, $CellContext`pe$ + $CellContext`rfbffx}], 
           Text[
           "\!\(\*SubscriptBox[\(B\), \(x\)]\)", $CellContext`pe$ + \
$CellContext`rfbffx + {-0.2, 0.2}], 
           Arrow[{$CellContext`pa$ - $CellContext`rfaffy, $CellContext`pa$}], 
           Text[
           "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`rfaffy + {0.3, 0.1}], 
           Arrow[{$CellContext`pe$ - $CellContext`rfbffy, $CellContext`pe$}], 
           Text[
           "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pe$ - \
$CellContext`rfbffy + {0.3, 0.1}], 
           
           Circle[$CellContext`pa$, $CellContext`rmaff, \
{$CellContext`sitaffai, $CellContext`sitaffae}], 
           Arrow[{$CellContext`maffe, $CellContext`maffi}], 
           Text[
           "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`maffe + {
             0, -0.2}], 
           
           Circle[$CellContext`pe$, $CellContext`rmbff, \
{$CellContext`sitaffbi, $CellContext`sitaffbe}], 
           Arrow[{$CellContext`mbffe, $CellContext`mbffi}], 
           Text[
           "\!\(\*SubscriptBox[\(M\), \(B\)]\)", $CellContext`mbffe + {0.3, 
             0.1}]}; $CellContext`dwf12$ = {
           Opacity[$CellContext`opa5$$ $CellContext`fpbeam], 
           Thickness[0.005], 
           Arrowheads[0.03], Red, 
           Arrow[{$CellContext`pa$ - $CellContext`rfafpx, $CellContext`pa$}], 
           Text[
           "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ - \
$CellContext`rfafpx + {0.2, 0.2}], 
           Arrow[{$CellContext`pe$, $CellContext`pe$ + $CellContext`rfbfpx}], 
           Text[
           "\!\(\*SubscriptBox[\(B\), \(x\)]\)", $CellContext`pe$ + \
$CellContext`rfbfpx + {-0.2, 0.2}], 
           Arrow[{$CellContext`pa$ - $CellContext`rfafpy, $CellContext`pa$}], 
           Text[
           "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`rfafpy + {0.3, 0.1}], 
           
           Arrow[{$CellContext`pe$ - $CellContext`rfbfpy + {
              0, (-$CellContext`W$)/2}, $CellContext`pe$ + {
              0, (-$CellContext`W$)/2}}], 
           Text[
           "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pe$ - \
$CellContext`rfbfpy + {0.3, -0.2}], 
           
           Circle[$CellContext`pa$, $CellContext`rmafp, \
{$CellContext`sitafpai, $CellContext`sitafpae}], 
           Arrow[{$CellContext`mafpe, $CellContext`mafpi}], 
           Text[
           "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`mafpe + {
             0, -0.2}]}; $CellContext`dwf13$ = {
           Opacity[$CellContext`opa5$$ $CellContext`frbeam], 
           Thickness[0.005], 
           Arrowheads[0.03], Red, 
           Arrow[{$CellContext`pa$ - $CellContext`rfafrx, $CellContext`pa$}], 
           Text[
           "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ - \
$CellContext`rfafrx + {0.2, 0.2}], 
           Arrow[{$CellContext`pa$ - $CellContext`rfafry, $CellContext`pa$}], 
           Text[
           "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`rfafry + {0.3, 0.1}], 
           
           Arrow[{$CellContext`pe$ - $CellContext`rfbfry + {
              0, (-$CellContext`W$)/2}, $CellContext`pe$ + {
              0, (-$CellContext`W$)/2}}], 
           Text[
           "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pe$ - \
$CellContext`rfbfry + {0.3, -0.2}], 
           
           Circle[$CellContext`pa$, $CellContext`rmafr, \
{$CellContext`sitafrai, $CellContext`sitafrae}], 
           Arrow[{$CellContext`mafre, $CellContext`mafri}], 
           Text[
           "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`mafre + {
             0, -0.2}]}; $CellContext`dwf14$ = {
           Opacity[$CellContext`opa5$$ $CellContext`fnbeam], 
           Thickness[0.005], 
           Arrowheads[0.03], Red, 
           If[Part[$CellContext`rfafnx, 1] > 0, 
            Arrow[{$CellContext`pa$ - $CellContext`rfafnx, $CellContext`pa$}], 
            
            Arrow[{$CellContext`pa$, $CellContext`pa$ + \
$CellContext`rfafnx}]], 
           If[Norm[$CellContext`rfafnx] > 0, 
            If[Part[$CellContext`rfafnx, 1] > 0, 
             Text[
             "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ - \
$CellContext`rfafnx + {0.2, 0.2}], 
             Text[
             "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ + \
$CellContext`rfafnx + {0.2, 0.2}]]], 
           If[Part[$CellContext`rfafny, 2] > 0, 
            Arrow[{$CellContext`pa$ - $CellContext`rfafny, $CellContext`pa$}], 
            
            Arrow[{$CellContext`pa$, $CellContext`pa$ + \
$CellContext`rfafny}]], 
           If[Norm[$CellContext`rfafny] > 0, 
            If[Part[$CellContext`rfafny, 2] > 0, 
             Text[
             "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`rfafny + {-0.3, -0.2}], 
             Text[
             "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ + \
$CellContext`rfafny + {-0.3, -0.2}]]], 
           If[Part[$CellContext`rfafnx, 1] > 0, 
            
            Circle[$CellContext`pa$ - $CellContext`rfafnx, \
$CellContext`rmafn, {$CellContext`sitafnai, $CellContext`sitafnae}], 
            
            Circle[$CellContext`pa$ + $CellContext`rfafnx, \
$CellContext`rmafn, {$CellContext`sitafnai, $CellContext`sitafnae}]], 
           If[Part[$CellContext`rfafnx, 1] > 0, 
            
            Arrow[{$CellContext`mafni + $CellContext`pa$ - \
$CellContext`rfafnx, $CellContext`mafne + $CellContext`pa$ - \
$CellContext`rfafnx}], 
            
            Arrow[{$CellContext`mafni + $CellContext`pa$ + \
$CellContext`rfafnx, $CellContext`mafne + $CellContext`pa$ + \
$CellContext`rfafnx}]], 
           If[Norm[$CellContext`mma] > 0, 
            If[Part[$CellContext`rfafnx, 1] > 0, 
             Text[
             "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`mafne + \
$CellContext`pa$ - $CellContext`rfafnx + Sign[$CellContext`mma] {0, -0.2}], 
             Text[
             "\!\(\*SubscriptBox[\(M\), \(A\)]\)", $CellContext`mafne + \
$CellContext`pa$ + $CellContext`rfafnx + 
              Sign[$CellContext`mma] {0, -0.2}]]]}; $CellContext`dwf15$ = {
           Opacity[$CellContext`opa5$$ $CellContext`ppbeam], 
           Thickness[0.005], 
           Arrowheads[0.03], Red, 
           Arrow[{$CellContext`pa$ - $CellContext`rfappx, $CellContext`pa$}], 
           Text[
           "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ - \
$CellContext`rfappx + {0.2, 0.2}], 
           
           Arrow[{$CellContext`pa$ - $CellContext`rfappy + {
              0, (-$CellContext`W$)/2}, $CellContext`pa$ + {
              0, (-$CellContext`W$)/2}}], 
           Text[
           "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`rfappy + {-0.3, -0.2}], 
           
           Arrow[{$CellContext`pe$ - $CellContext`rfbppy + {
              0, (-$CellContext`W$)/2}, $CellContext`pe$ + {
              0, (-$CellContext`W$)/2}}], 
           Text[
           "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pe$ - \
$CellContext`rfbppy + {0.3, -0.2}], 
           Arrow[{$CellContext`pe$, $CellContext`pe$ + $CellContext`rfbppx}], 
           Text[
           "\!\(\*SubscriptBox[\(B\), \(x\)]\)", $CellContext`pe$ + \
$CellContext`rfbppx + {-0.2, 0.2}]}; $CellContext`dwf16$ = {
           Opacity[$CellContext`opa5$$ $CellContext`prbeam], 
           Thickness[0.005], 
           Arrowheads[0.03], Red, 
           If[Part[$CellContext`rfaprx, 1] > 0, 
            Arrow[{$CellContext`pa$ - $CellContext`rfaprx, $CellContext`pa$}], 
            
            Arrow[{$CellContext`pa$, $CellContext`pa$ + \
$CellContext`rfaprx}]], 
           If[Norm[$CellContext`rfaprx] > 0, 
            If[Part[$CellContext`rfaprx, 1] > 0, 
             Text[
             "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ - \
$CellContext`rfaprx + {0.2, 0.2}], 
             Text[
             "\!\(\*SubscriptBox[\(A\), \(x\)]\)", $CellContext`pa$ + \
$CellContext`rfaprx + {0.2, 0.2}]]], 
           If[Part[$CellContext`rfapry, 2] > 0, 
            
            Arrow[{$CellContext`pa$ - $CellContext`rfapry + {
               0, (-$CellContext`W$)/2}, $CellContext`pa$ + {
               0, (-$CellContext`W$)/2}}], 
            
            Arrow[{$CellContext`pa$ + {
               0, (-$CellContext`W$)/
                2}, $CellContext`pa$ + $CellContext`rfapry + {
               0, (-$CellContext`W$)/2}}]], 
           If[Norm[$CellContext`rfapry] > 0, 
            If[Part[$CellContext`rfapry, 2] > 0, 
             Text[
             "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`rfapry + {-0.3, -0.2}], 
             Text[
             "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ + \
$CellContext`rfapry + {-0.3, -0.2}]]], 
           If[Part[$CellContext`rfbpry, 2] > 0, 
            
            Arrow[{$CellContext`pe$ - $CellContext`rfbpry + {
               0, (-$CellContext`W$)/2}, $CellContext`pe$ + {
               0, (-$CellContext`W$)/2}}], 
            
            Arrow[{$CellContext`pe$ + {
               0, (-$CellContext`W$)/
                2}, $CellContext`pe$ + $CellContext`rfbpry + {
               0, (-$CellContext`W$)/2}}]], 
           If[Norm[$CellContext`rfbpry] > 0, 
            If[Part[$CellContext`rfbpry, 2] > 0, 
             Text[
             "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pe$ - \
$CellContext`rfbpry + {0.3, -0.2}], 
             Text[
             "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pe$ + \
$CellContext`rfbpry + {0.3, -0.2}]]]}; $CellContext`dwf17$ = {
           Opacity[$CellContext`opa5$$ $CellContext`rrbeam], 
           Thickness[0.005], 
           Arrowheads[0.03], Red, 
           If[Part[$CellContext`rfapry, 2] > 0, 
            
            Arrow[{$CellContext`pa$ - $CellContext`rfapry + {
               0, (-$CellContext`W$)/2}, $CellContext`pa$ + {
               0, (-$CellContext`W$)/2}}], 
            
            Arrow[{$CellContext`pa$ + {
               0, (-$CellContext`W$)/
                2}, $CellContext`pa$ + $CellContext`rfapry + {
               0, (-$CellContext`W$)/2}}]], 
           If[Part[$CellContext`rfapry, 2] > 0, 
            Text[
            "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ - \
$CellContext`rfapry + {0.3, -0.2}], 
            Text[
            "\!\(\*SubscriptBox[\(A\), \(y\)]\)", $CellContext`pa$ + \
$CellContext`rfapry + {0.3, -0.2}]], 
           If[Part[$CellContext`rfbpry, 2] > 0, 
            
            Arrow[{$CellContext`pe$ - $CellContext`rfbpry + {
               0, (-$CellContext`W$)/2}, $CellContext`pe$ + {
               0, (-$CellContext`W$)/2}}], 
            
            Arrow[{$CellContext`pe$ + {
               0, (-$CellContext`W$)/
                2}, $CellContext`pe$ + $CellContext`rfbpry + {
               0, (-$CellContext`W$)/2}}]], 
           If[Part[$CellContext`rfbpry, 2] > 0, 
            Text[
            "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pe$ - \
$CellContext`rfbpry + {0.3, -0.2}], 
            Text[
            "\!\(\*SubscriptBox[\(B\), \(y\)]\)", $CellContext`pe$ + \
$CellContext`rfbpry + {0.3, -0.2}]]}; $CellContext`dw1$ = 
         Graphics[{$CellContext`dwf0$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$, $CellContext`dwf4$, \
$CellContext`dwf5$, $CellContext`dwf6$, $CellContext`dwf7$, \
$CellContext`dwf8$, $CellContext`dwf9$, $CellContext`dwf10$, \
$CellContext`dwf11$, $CellContext`dwf12$, $CellContext`dwf13$, \
$CellContext`dwf14$, $CellContext`dwf15$, $CellContext`dwf16$, \
$CellContext`dwf17$}, 
           PlotRange -> {{(-0.5) $CellContext`size$, 
              1.3 $CellContext`size$}, {(-0.75) $CellContext`size$, 
              0.8 $CellContext`size$}}, ImageSize -> 280, Frame -> False]; 
        Show[$CellContext`dw1$]], 
      "Specifications" :> {{{$CellContext`opa1$$, 0, 
          Row[{"Coordinates visibility", 
            Spacer[20]}]}, {1 -> "On", 0 -> "off"}, ControlType -> 
         RadioButton, ControlPlacement -> 1}, {{$CellContext`opa2$$, 1, 
          Row[{"Constraints at the left end of beam", 
            Spacer[20]}]}, {1 -> "Fixed", 0 -> "Smooth pin", -1 -> "Roller"}, 
         ControlType -> RadioButton, ControlPlacement -> 
         2}, {{$CellContext`opa3$$, -1, 
          Row[{"Constraints at the right end of beam", 
            Spacer[12]}]}, {
         1 -> "Fixed", 0 -> "Smooth pin", -1 -> "Roller", -2 -> "None"}, 
         ControlType -> RadioButton, ControlPlacement -> 
         3}, {{$CellContext`opa3$$, -1, 
          Row[{"Constraints at the right end of beam", 
            Spacer[12]}]}, {0 -> "Smooth pin", -1 -> "Roller"}, ControlType -> 
         RadioButton, ControlPlacement -> 4}, {{$CellContext`opa3$$, -1, 
          Row[{"Constraints at the right end of beam", 
            Spacer[15]}]}, {-1 -> "Roller"}, ControlType -> RadioButton, 
         ControlPlacement -> 5}, {{$CellContext`pf$$, 0.3, 
          Row[{"Position of force [m]", 
            Spacer[70]}]}, 0, 1, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 6}, {{$CellContext`mf$$, 1, 
          Row[{"Magnitude of force [kN]", 
            Spacer[48]}]}, 0, 2, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 7}, {{$CellContext`sita$$, 90, 
          Row[{"Direction of Force [\[Degree]]", 
            Spacer[68]}]}, 0, 360, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 8}, {{$CellContext`pm$$, 0.6, 
          Row[{"Position of moment [m]", 
            Spacer[52]}]}, 0, 1, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 9}, {{$CellContext`mm$$, 1, 
          Row[{"Magnitude of moment [kN\[CenterDot]m]", 
            Spacer[18]}]}, 0, 2, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 10}, {{$CellContext`opa4$$, 1, 
          Row[{"Direction of Moment", 
            Spacer[60]}]}, {1 -> "CCW", 0 -> "CW"}, ControlType -> 
         RadioButton, ControlPlacement -> 11}, {{$CellContext`opa5$$, 0, 
          Row[{"Reactive Force & Moment", 
            Spacer[32]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 12}, 
        Grid[{{
           Manipulate`Place[1]}, {
           Manipulate`Place[2]}, {
           PaneSelector[{1 -> Column[{
                Manipulate`Place[3]}], 0 -> Column[{
                Manipulate`Place[4]}], -1 -> Column[{
                Manipulate`Place[5]}]}, 
            Dynamic[$CellContext`opa2$$]]}, {
           Manipulate`Place[6]}, {
           Manipulate`Place[7]}, {
           Manipulate`Place[8]}, {
           Manipulate`Place[9]}, {
           Manipulate`Place[10]}, {
           Manipulate`Place[11]}, {
           Manipulate`Place[12]}, {
           Row[{
             Dynamic[
              If[$CellContext`opa5$$ == 1, $CellContext`temp1, 
               Invisible[$CellContext`temp]]]}]}, {
           Row[{
             Dynamic[
              If[$CellContext`opa5$$ == 1, $CellContext`temp2, 
               Invisible[$CellContext`temp]]]}]}, {
           Row[{
             Dynamic[
              If[$CellContext`opa5$$ == 1, $CellContext`temp3, 
               Invisible[$CellContext`temp]]]}]}, {
           Row[{
             Dynamic[
              If[$CellContext`opa5$$ == 1, $CellContext`temp4, 
               Invisible[$CellContext`temp]]]}]}, {
           Row[{
             Dynamic[
              If[$CellContext`opa5$$ == 1, $CellContext`temp5, 
               Invisible[$CellContext`temp]]]}]}, {
           Row[{
             Dynamic[
              If[$CellContext`opa5$$ == 1, $CellContext`temp6, 
               Invisible[$CellContext`temp]]]}]}, {
           Row[{
             Dynamic[
              If[
               And[$CellContext`opa5$$ == 1, 
                
                Or[$CellContext`fnbeam == 1, $CellContext`prbeam == 
                 1]], $CellContext`temp7, 
               Invisible[$CellContext`temp]]]}]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.5}]}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{1022., {351., 359.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 ExpressionUUID -> "40edc86d-39b7-43cb-9800-96fa6c3bd437"]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.35 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, WindowSize -> {775, 872}, 
  WindowMargins -> {{225, Automatic}, {-15, Automatic}}, FrontEndVersion -> 
  "11.0 for Microsoft Windows (64-bit) (July 28, 2016)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 257, 7, 208, "Title"],
Cell[1746, 44, 1497, 28, 148, "Text"],
Cell[3246, 74, 90861, 1651, 732, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature uxTQdql9hSJxPAKMHOf0ThVr *)
